@@ -436,10 +436,6 @@ static void rb_curl_mutli_handle_complete(VALUE self, CURL *easy_handle, int res
     //rb_funcall( rb_easy_get("failure_proc"), idCall, 2, easy, rb_curl_easy_error(result) );
   }
 
-  if (val == Qfalse) {
-    rb_warn("uncaught exception from callback");
-  }
-
 }
 
 static void rb_curl_multi_read_info(VALUE self, CURLM *multi_handle) {
